var languageNames = {
"en-US": "Inggris (USA)",
"sq": "Albania",
"am": "Amharik",
"ar": "Arab",
"ast": "Asturian",
"bn": "Benggala",
"bn-IN": "Benggala (India)",
"bs": "Bosnia",
"bg": "Bulgaria",
"ca": "Katalan",
"ca-valencia": "Katalan (Valencia)",
"zh-CN": "Cina (Disederhanakan)",
"zh-TW": "Cina (Tradisional)",
"hr": "Kroasia",
"cs": "Czech",
"da": "Denmark",
"nl": "Belanda",
"dz": "Bhutan",
"en-GB": "Inggris (UK)",
"en-ZA": "Inggris (SA)",
"eo": "Esperanto",
"et": "Estonia",
"eu": "Basque",
"fi": "Finlandia",
"fr": "Perancis",
"gl": "Galasia",
"ka": "Georgia",
"de": "Jerman",
"el": "Yunani",
"gu": "Gujarat",
"he": "Ibrani",
"hi": "India",
"hu": "Hungaria",
"id": "Indonesia",
"is": "Islandia",
"it": "Italia",
"ja": "Jepang",
"km": "Kamboja",
"ko": "Korea",
"lo": "Laos",
"lv": "Latvi",
"lt": "Lithuania",
"mk": "Makedonia",
"ne": "Nepal",
"nn": "Norwegia Baru",
"nb": "Norwegia",
"om": "Etiopia",
"pl": "Polandia",
"pt": "Portugis",
"pt-BR": "Portugis (Brasil)",
"ro": "Romania",
"ru": "Rusia",
"sid": "Sidama",
"si": "Sri Lanka",
"sk": "Slowakia",
"sl": "Slovenia",
"dsb": "Sorbia (Hilir)",
"dsb": "Sorbia (Hulu)",
"es": "Spanyol",
"sv": "Swedia",
"tg": "Tajikistan",
"ta": "Tamil",
"bo": "Tibetan",
"tr": "Turki",
"ug": "Uighur",
"uk": "Ukrania",
"vi": "Vietnam",
};
